package mjml //nolint:testpackage

import (
	"testing"

	"github.com/stretchr/testify/require"
)

var mjmlSrc = `
<mjml>
  <mj-body>
    <mj-section>
      <mj-column>
        <mj-text>hello world</mj-text>
      </mj-column>
    </mj-section>
  </mj-body>
</mjml>
`

var mjmlSrcWithError = `
<mjml>
  <mj-body>
    <mj-section invalid="hi">
      <mj-column>
        <mj-text invalid=true>hello world</mj-text>
      </mj-column>
    </mj-section>
  </mj-body>
</mjml>
`

var mjmlSrcInvalidMJML = `
NOT A MJML CONTENT
`

func BenchmarkDukTapeInit(b *testing.B) {
	for range b.N {
		ctx, err := initDukTapeCtx()
		require.NoError(b, err)
		ctx.DestroyHeap()
	}
}

func BenchmarkDukTapeRender(b *testing.B) {
	ctx, err := initDukTapeCtx()
	require.NoError(b, err)

	defer ctx.DestroyHeap()
	b.ResetTimer()

	for range b.N {
		_, err := renderDukTape(ctx, mjmlSrc, Options{
			Beautify:        true,
			ValidationLevel: ValidationStrict,
		})
		require.NoError(b, err)
	}
}

func TestDukType(t *testing.T) {
	t.Run("Simple", func(t *testing.T) {
		ctx, err := initDukTapeCtx()
		require.NoError(t, err)

		defer ctx.DestroyHeap()
		t.Log(renderDukTape(ctx, mjmlSrc, Options{
			Beautify:        true,
			ValidationLevel: ValidationStrict,
		}))
	})
	t.Run("WithError", func(t *testing.T) {
		ctx, err := initDukTapeCtx()
		require.NoError(t, err)

		defer ctx.DestroyHeap()
		r, err := renderDukTape(ctx, mjmlSrcWithError, Options{
			Beautify:        true,
			ValidationLevel: ValidationSoft,
		})
		require.NoError(t, err)
		t.Log(r)
	})
	t.Run("Invalid-mjml", func(t *testing.T) {
		ctx, err := initDukTapeCtx()
		require.NoError(t, err)

		defer ctx.DestroyHeap()
		r, err := renderDukTape(ctx, mjmlSrcInvalidMJML, Options{
			Beautify:        true,
			ValidationLevel: ValidationSoft,
		})
		require.NoError(t, err)
		t.Log(r)
	})
}

/*
func TestGoja(t *testing.T) {
	vm, err := initGoja()
	require.NoError(t, err)
	renderGoja(vm, mjmlSrc)
}
*/
