package utils_test

import (
	"reflect"
	"testing"

	"orus.io/orus-io/rednerd/utils"
)

func TestStringSliceFilterOut(t *testing.T) {
	tests := []struct {
		name   string
		input  []string
		filter []string
		want   []string
	}{
		{"No filtering", []string{"a", "b", "c"}, []string{}, []string{"a", "b", "c"}},
		{"Filter one element", []string{"a", "b", "c"}, []string{"b"}, []string{"a", "c"}},
		{"Filter multiple elements", []string{"a", "b", "c", "d"}, []string{"b", "d"}, []string{"a", "c"}},
		{"Filter all elements", []string{"a", "b", "c"}, []string{"a", "b", "c"}, []string{}},
		{"Filter with duplicates", []string{"a", "b", "b", "c"}, []string{"b"}, []string{"a", "c"}},
		{"Empty input slice", []string{}, []string{"a", "b"}, []string{}},
		{"Empty filter slice", []string{"x", "y", "z"}, []string{}, []string{"x", "y", "z"}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			got := utils.StringSliceFilterOut(tt.input, tt.filter...)
			if !reflect.DeepEqual(got, tt.want) {
				t.Errorf("StringSliceFilterOut(%v, %v) = %v; want %v", tt.input, tt.filter, got, tt.want)
			}
		})
	}
}
